Struct WpImageDescriptionCreatorIccV1
pub struct WpImageDescriptionCreatorIccV1 { /* private fields */ }wayland and Linux only.Expand description
holder of image description ICC information
This type of object is used for collecting all the information required to create a wp_image_description_v1 object from an ICC file. A complete set of required parameters consists of these properties:
- ICC file
Each required property must be set exactly once if the client is to create an image description. The set requests verify that a property was not already set. The create request verifies that all required properties are set. There may be several alternative requests for setting each property, and in that case the client must choose one of them.
Once all properties have been set, the create request must be used to create the image description object, destroying the creator in the process.
The link between a pixel value (a device value in ICC) and its respective colorimetry is defined by the details of the particular ICC profile. Those details also determine when colorimetry becomes undefined.
See also the Request enum for this interface.